.. _about:

About
=====

Licence
^^^^^^^

ETL Helper is distributed under the `LGPL v3.0 licence <LICENSE>`__.
Copyright: © BGS / UKRI 2019

Presentations
^^^^^^^^^^^^^

For a high level introduction to ``etlhelper``, see the FOSS4GUK 2019
presentation *Open Source Spatial ETL with Python and Apache Airflow*:
`video <https://www.youtube.com/watch?v=12rzUW4ps74&feature=youtu.be&t=6238>`__
(20 mins), `slides <https://volcan01010.github.io/FOSS4G2019-talk>`__.